# IOBES

[![PyPi Version](https://img.shields.io/pypi/v/iobes)](https://pypi.org/project/iobes/) [![Actions Status](https://github.com/blester125/iobes/workflows/Unit%20Test/badge.svg)](https://github.com/blester125/iobes/actions) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
